pub struct SystemPolicyV1 { /* private fields */ }Expand description
Implements a client for the Binary Authorization API.
Example
async fn sample(
project_id: &str,
) -> anyhow::Result<()> {
let client = SystemPolicyV1::builder().build().await?;
let response = client.get_system_policy()
.set_name(format!("projects/{project_id}/policy"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
API for working with the system policy.
Configuration
To configure SystemPolicyV1 use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://binaryauthorization.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SystemPolicyV1 holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SystemPolicyV1 in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SystemPolicyV1
impl SystemPolicyV1
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SystemPolicyV1.
let client = SystemPolicyV1::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SystemPolicyV1 + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SystemPolicyV1 + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_system_policy(&self) -> GetSystemPolicy
pub fn get_system_policy(&self) -> GetSystemPolicy
Gets the current system policy in the specified location.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &SystemPolicyV1, project_id: &str
) -> Result<()> {
let response = client.get_system_policy()
.set_name(format!("projects/{project_id}/policy"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &SystemPolicyV1
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &SystemPolicyV1
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &SystemPolicyV1
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SystemPolicyV1
impl Clone for SystemPolicyV1
Sourcefn clone(&self) -> SystemPolicyV1
fn clone(&self) -> SystemPolicyV1
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more