pub struct ValidationHelperV1 { /* private fields */ }Expand description
Implements a client for the Binary Authorization API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = ValidationHelperV1::builder().build().await?;
let response = client.validate_attestation_occurrence()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
BinAuthz Attestor verification
Configuration
To configure ValidationHelperV1 use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://binaryauthorization.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ValidationHelperV1 holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ValidationHelperV1 in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ValidationHelperV1
impl ValidationHelperV1
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ValidationHelperV1.
let client = ValidationHelperV1::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ValidationHelperV1 + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ValidationHelperV1 + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn validate_attestation_occurrence(&self) -> ValidateAttestationOccurrence
pub fn validate_attestation_occurrence(&self) -> ValidateAttestationOccurrence
Returns whether the given Attestation for the given image URI
was signed by the given Attestor
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &ValidationHelperV1
) -> Result<()> {
let response = client.validate_attestation_occurrence()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &ValidationHelperV1
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &ValidationHelperV1
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &ValidationHelperV1
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for ValidationHelperV1
impl Clone for ValidationHelperV1
Sourcefn clone(&self) -> ValidationHelperV1
fn clone(&self) -> ValidationHelperV1
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more