Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ASCII-armored representation of a PGP public key, as the entire output by
the command gpg --export --armor foo@example.com (either LF or CRLF
line endings).
When using this field, id should be left blank. The Binary
Authorization API handlers will calculate the ID and fill it in
automatically. Binary Authorization computes this ID as the OpenPGP
RFC4880 V4 fingerprint, represented as upper-case hex. If id is
provided by the caller, it will be overwritten by the API-calculated ID.
A raw PKIX SubjectPublicKeyInfo format public key.
NOTE: id may be explicitly provided by the caller when using this
type of public key, but it MUST be a valid RFC3986 URI. If id is left
blank, a default one will be computed based on the digest of the DER
encoding of the public key.