PkixPublicKey

Struct PkixPublicKey 

#[non_exhaustive]
pub struct PkixPublicKey { pub public_key_pem: String, pub signature_algorithm: SignatureAlgorithm, pub key_id: String, /* private fields */ }
A public key in the PkixPublicKey format. Public keys of this type are typically textually encoded using the PEM format.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
public_key_pem: String

A PEM-encoded public key, as described in https://tools.ietf.org/html/rfc7468#section-13

signature_algorithm: SignatureAlgorithm

The signature algorithm used to verify a message against a signature using this key. These signature algorithm must match the structure and any object identifiers encoded in public_key_pem (i.e. this algorithm must match that of the public key).

key_id: String

Optional. The ID of this public key. Signatures verified by Binary Authorization must include the ID of the public key that can be used to verify them. The ID must match exactly contents of the key_id field exactly.

The ID may be explicitly provided by the caller, but it MUST be a valid RFC3986 URI. If key_id is left blank and this PkixPublicKey is not used in the context of a wrapper (see next paragraph), a default key ID will be computed based on the digest of the DER encoding of the public key.

If this PkixPublicKey is used in the context of a wrapper that has its own notion of key ID (e.g. AttestorPublicKey), then this field can either match that value exactly, or be left blank, in which case it behaves exactly as though it is equal to that wrapper value.

Implementations

Source

impl PkixPublicKey

pub fn new() -> Self

Creates a new default instance.

pub fn set_public_key_pem<T: Into<String>>(self, v: T) -> Self

Sets the value of public_key_pem.

Example
let x = PkixPublicKey::new().set_public_key_pem("example");
pub fn set_signature_algorithm<T: Into<SignatureAlgorithm>>(self, v: T) -> Self

Sets the value of signature_algorithm.

Example
use google_cloud_binaryauthorization_v1::model::pkix_public_key::SignatureAlgorithm;
let x0 = PkixPublicKey::new().set_signature_algorithm(SignatureAlgorithm::RsaPss2048Sha256);
let x1 = PkixPublicKey::new().set_signature_algorithm(SignatureAlgorithm::RsaSignPss2048Sha256);
let x2 = PkixPublicKey::new().set_signature_algorithm(SignatureAlgorithm::RsaPss3072Sha256);
pub fn set_key_id<T: Into<String>>(self, v: T) -> Self

Sets the value of key_id.

Example
let x = PkixPublicKey::new().set_key_id("example");