pub trait SystemPolicyV1:
Debug
+ Send
+ Sync {
// Provided methods
fn get_system_policy(
&self,
_req: GetSystemPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send { ... }
fn set_iam_policy(
&self,
_req: SetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send { ... }
fn get_iam_policy(
&self,
_req: GetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send { ... }
fn test_iam_permissions(
&self,
_req: TestIamPermissionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::SystemPolicyV1.
Application developers may need to implement this trait to mock
client::SystemPolicyV1. In other use-cases, application developers only
use client::SystemPolicyV1 and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn get_system_policy(
&self,
_req: GetSystemPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send
fn get_system_policy( &self, _req: GetSystemPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Policy>>> + Send
Implements super::client::SystemPolicyV1::get_system_policy.
Sourcefn set_iam_policy(
&self,
_req: SetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send
fn set_iam_policy( &self, _req: SetIamPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Policy>>> + Send
Implements super::client::SystemPolicyV1::set_iam_policy.
Sourcefn get_iam_policy(
&self,
_req: GetIamPolicyRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Policy>>> + Send
fn get_iam_policy( &self, _req: GetIamPolicyRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Policy>>> + Send
Implements super::client::SystemPolicyV1::get_iam_policy.
Sourcefn test_iam_permissions(
&self,
_req: TestIamPermissionsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send
fn test_iam_permissions( &self, _req: TestIamPermissionsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<TestIamPermissionsResponse>>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".