pub struct BinauthzManagementServiceV1 { /* private fields */ }Expand description
Implements a client for the Binary Authorization API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = BinauthzManagementServiceV1::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_attestors()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Google Cloud Management Service for Binary Authorization admission policies and attestation authorities.
This API implements a REST model with the following objects:
Configuration
To configure BinauthzManagementServiceV1 use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://binaryauthorization.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
BinauthzManagementServiceV1 holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap BinauthzManagementServiceV1 in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl BinauthzManagementServiceV1
impl BinauthzManagementServiceV1
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for BinauthzManagementServiceV1.
let client = BinauthzManagementServiceV1::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: BinauthzManagementServiceV1 + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: BinauthzManagementServiceV1 + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_policy(&self) -> GetPolicy
pub fn get_policy(&self) -> GetPolicy
A policy specifies the attestors that must attest to a container image, before the project is allowed to deploy that image. There is at most one policy per project. All image admission requests are permitted if a project has no policy.
Gets the policy for this project. Returns a default policy if the project does not have one.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, name: &str
) -> Result<()> {
let response = client.get_policy()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_policy(&self) -> UpdatePolicy
pub fn update_policy(&self) -> UpdatePolicy
Creates or updates a project’s policy, and returns a copy of the new policy. A policy is always updated as a whole, to avoid race conditions with concurrent policy enforcement (or management!) requests. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed.
Example
use google_cloud_binaryauthorization_v1::model::Policy;
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, name: &str
) -> Result<()> {
let response = client.update_policy()
.set_policy(
Policy::new().set_name(name)/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_attestor(&self) -> CreateAttestor
pub fn create_attestor(&self) -> CreateAttestor
Creates an attestor, and returns a copy of the new attestor. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed, ALREADY_EXISTS if the attestor already exists.
Example
use google_cloud_binaryauthorization_v1::model::Attestor;
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, parent: &str
) -> Result<()> {
let response = client.create_attestor()
.set_parent(parent)
.set_attestor_id("attestor_id_value")
.set_attestor(
Attestor::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_attestor(&self) -> GetAttestor
pub fn get_attestor(&self) -> GetAttestor
Gets an attestor. Returns NOT_FOUND if the attestor does not exist.
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, name: &str
) -> Result<()> {
let response = client.get_attestor()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_attestor(&self) -> UpdateAttestor
pub fn update_attestor(&self) -> UpdateAttestor
Updates an attestor. Returns NOT_FOUND if the attestor does not exist.
Example
use google_cloud_binaryauthorization_v1::model::Attestor;
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, name: &str
) -> Result<()> {
let response = client.update_attestor()
.set_attestor(
Attestor::new().set_name(name)/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_attestors(&self) -> ListAttestors
pub fn list_attestors(&self) -> ListAttestors
Lists attestors. Returns INVALID_ARGUMENT if the project does not exist.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &BinauthzManagementServiceV1, parent: &str
) -> Result<()> {
let mut list = client.list_attestors()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_attestor(&self) -> DeleteAttestor
pub fn delete_attestor(&self) -> DeleteAttestor