pub struct ValidationHelperV1 { /* private fields */ }Expand description
Implements a client for the Binary Authorization API.
Example
let client = ValidationHelperV1::builder().build().await?;
let response = client.validate_attestation_occurrence()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
BinAuthz Attestor verification
Configuration
To configure ValidationHelperV1 use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://binaryauthorization.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ValidationHelperV1 holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ValidationHelperV1 in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ValidationHelperV1
impl ValidationHelperV1
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ValidationHelperV1.
let client = ValidationHelperV1::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ValidationHelperV1 + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ValidationHelperV1 + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn validate_attestation_occurrence(&self) -> ValidateAttestationOccurrence
pub fn validate_attestation_occurrence(&self) -> ValidateAttestationOccurrence
Returns whether the given Attestation for the given image URI was signed by the given Attestor
Example
use google_cloud_binaryauthorization_v1::Result;
async fn sample(
client: &ValidationHelperV1
) -> Result<()> {
let response = client.validate_attestation_occurrence()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for ValidationHelperV1
impl Clone for ValidationHelperV1
Sourcefn clone(&self) -> ValidationHelperV1
fn clone(&self) -> ValidationHelperV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ValidationHelperV1
impl !RefUnwindSafe for ValidationHelperV1
impl Send for ValidationHelperV1
impl Sync for ValidationHelperV1
impl Unpin for ValidationHelperV1
impl UnsafeUnpin for ValidationHelperV1
impl !UnwindSafe for ValidationHelperV1