Defines additional types related to PkixPublicKey.
Enums
- Signature
Algorithm - Represents a signature algorithm and other information necessary to verify signatures with a given public key. This is based primarily on the public key types supported by Tink’s PemKeyType, which is in turn based on KMS’s supported signing algorithms. In the future, Binary Authorization might support additional public key types independently of Tink and/or KMS.