SignatureAlgorithm

Enum SignatureAlgorithm 

#[non_exhaustive]
pub enum SignatureAlgorithm {
Show 21 variants Unspecified, RsaPss2048Sha256, RsaSignPss2048Sha256, RsaPss3072Sha256, RsaSignPss3072Sha256, RsaPss4096Sha256, RsaSignPss4096Sha256, RsaPss4096Sha512, RsaSignPss4096Sha512, RsaSignPkcs12048Sha256, RsaSignPkcs13072Sha256, RsaSignPkcs14096Sha256, RsaSignPkcs14096Sha512, EcdsaP256Sha256, EcSignP256Sha256, EcdsaP384Sha384, EcSignP384Sha384, EcdsaP521Sha512, EcSignP521Sha512, MlDsa65, UnknownValue(UnknownValue),
}
Represents a signature algorithm and other information necessary to verify signatures with a given public key. This is based primarily on the public key types supported by Tink’s PemKeyType, which is in turn based on KMS’s supported signing algorithms. In the future, Binary Authorization might support additional public key types independently of Tink and/or KMS.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Not specified.



RsaPss2048Sha256

RSASSA-PSS 2048 bit key with a SHA256 digest.



RsaSignPss2048Sha256

RSASSA-PSS 2048 bit key with a SHA256 digest.



RsaPss3072Sha256

RSASSA-PSS 3072 bit key with a SHA256 digest.



RsaSignPss3072Sha256

RSASSA-PSS 3072 bit key with a SHA256 digest.



RsaPss4096Sha256

RSASSA-PSS 4096 bit key with a SHA256 digest.



RsaSignPss4096Sha256

RSASSA-PSS 4096 bit key with a SHA256 digest.



RsaPss4096Sha512

RSASSA-PSS 4096 bit key with a SHA512 digest.



RsaSignPss4096Sha512

RSASSA-PSS 4096 bit key with a SHA512 digest.



RsaSignPkcs12048Sha256

RSASSA-PKCS1-v1_5 with a 2048 bit key and a SHA256 digest.



RsaSignPkcs13072Sha256

RSASSA-PKCS1-v1_5 with a 3072 bit key and a SHA256 digest.



RsaSignPkcs14096Sha256

RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA256 digest.



RsaSignPkcs14096Sha512

RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA512 digest.



EcdsaP256Sha256

ECDSA on the NIST P-256 curve with a SHA256 digest.



EcSignP256Sha256

ECDSA on the NIST P-256 curve with a SHA256 digest.



EcdsaP384Sha384

ECDSA on the NIST P-384 curve with a SHA384 digest.



EcSignP384Sha384

ECDSA on the NIST P-384 curve with a SHA384 digest.



EcdsaP521Sha512

ECDSA on the NIST P-521 curve with a SHA512 digest.



EcSignP521Sha512

ECDSA on the NIST P-521 curve with a SHA512 digest.



MlDsa65

ML-DSA-65 Post-Quantum Cryptography signature algorithm.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using SignatureAlgorithm::value or SignatureAlgorithm::name.

Implementations

Source

impl SignatureAlgorithm

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.